@@ -63,7 +63,7 @@ def parse_args() -> argparse.Namespace:
     _parser.add_argument('--max_mline', required=False, default=None, type=int, help=MAX_MLINE_DESCRIPTION)
     _parser.add_argument('--seed', required=False, default=None, type=int, help=MAX_SEED_DESCRIPTION)
     _parser.add_argument('--xcorr_filter', required=False, default=None, type=float, help=XCORR_FILTER_DESCRIPTION)
-    _parser.add_argument('--verbosity', required=False, default=1, type=int, choices=[0,1,2,3], help=VERBOSITY_DESCRIPTION)
+    _parser.add_argument('--verbosity', required=False, default=2, type=int, choices=[0,1,2,3], help=VERBOSITY_DESCRIPTION)
     _parser.add_argument('--filter_level', required=False, default=0, type=int, choices=[0,1,2], help=FILTER_LEVEL_DESCRIPTION)
 
     return _parser.parse_args()
@@ -131,7 +131,7 @@ def run():
     if args.dta_params:
         dta_params = Path(args.dta_params).open()
 
-    print(args)
+    logging.info(args)
     alignment_figs, pin_df, dta_filter_content = mokafilter((sqt_ios, sqt_stems), (fasta_ios, fasta_stems),
                                                             args.protein_fdr, args.peptide_fdr, args.psm_fdr,
                                                             args.min_peptides,
@@ -156,7 +156,7 @@ def run():
             if fig is None:
                 continue
             png_name = f'{stem}_mass_alignment.png'
-            print(f'Saving alignment plot to {png_name}')
+            logging.info(f'Saving alignment plot to {png_name}')
             fig.savefig(png_name)
 
     if dta_params:
@@ -257,18 +257,18 @@ def mokafilter(sqts: Tuple[Iterator[IO[str]], List[str]],
         ['filter_level', filter_level]
     ], headers=['Argument', 'Value'], missingval='None')
 
-    print(tabulated_args)
+    logging.info(tabulated_args)
 
     # Set the random seed:
     if seed:
-        print(f'Setting random seed: {seed}')
+        logging.info(f'Setting random seed: {seed}')
         np.random.seed(seed)
 
     sqt_dfs = [convert_to_csv(sqt_io, sqt_stem, xcorr_filter, max_mline) for sqt_io, sqt_stem in zip(sqts[0], sqts[1])]
 
     alignment_figs = []
     if mass_alignment is True:
-        print(f'Aligning masses...')
+        logging.info(f'Aligning masses...')
         for i, sqt_df in enumerate(sqt_dfs):
             fig = None
             try:
